@@ -56,13 +56,11 @@ def focus_tracker(donot_watch_list):
             pass
 
 def main():
-    print("Welcome to Focus-Tracker, You can list out your distractions and my duty is to save your time by avoiding them")
-    print("To Start please execute : focus_tracker_test -start START")
     parser=argparse.ArgumentParser()
     parser.add_argument("-start",help="Start Focus Mode")
     args = parser.parse_args()
     if args.start:
-        print("Please enter the names of websites/apps which you donot want to open \nPlease press 'q' after you have finished the list")
+        print("Please enter the names of websites/apps which you donot want to open by pressing 'ENTER' after every name \nPlease press 'q' after you have finished the list")
         donot_watch_list=[]
         while True:
             inp=str(input())
@@ -70,6 +68,9 @@ def main():
                 break
             donot_watch_list.append(inp)
         focus_tracker(donot_watch_list)
+    else:
+        print("Welcome to Focus-Tracker, You can list out your distractions and my duty is to save your time by avoiding them")
+        print("To Start please execute : focus_tracker_test -start START")
 
 if __name__=='__main__':
     main()
